@@ -28,6 +28,8 @@ from bowl.cli_opts import snapshot
 from bowl.cli_opts import snapshots
 from bowl.cli_opts import start
 from bowl.cli_opts import stop
+from bowl.cli_opts import subtract
+from bowl.cli_opts import test
 from bowl.cli_opts import unlink
 from bowl.cli_opts import update
 from bowl.cli_opts import version
@@ -38,6 +40,7 @@ class cli(object):
     """
     def parse_args(self):
         default_metadata_path = "~/.bowl"
+        default_path = "/bowl"
 
         parser = argparse.ArgumentParser()
 
@@ -51,7 +54,7 @@ class cli(object):
         parse_add.add_argument('VERSION',
                                 help='specify version of operating system')
         parse_add.add_argument('TYPE',
-                                help='specify type of service (database, environment, service)')
+                                help='specify type of service (database, environment, service, tool)')
         parse_add.add_argument('NAME',
                                 help='specify name of service')
         parse_add.add_argument('JSON',
@@ -138,6 +141,9 @@ class cli(object):
         # info
         parse_info = subparsers.add_parser('info',
                                            help='display system-wide information')
+        parse_info.add_argument('--metadata_path', '-m',
+                                default=default_metadata_path,
+                                help='metadata path, default '+default_metadata_path)
         parse_info.add_argument('-z',
                                 action='store_true',
                                 help='do not print any output')
@@ -148,6 +154,12 @@ class cli(object):
                                            help='kill running container')
         parse_kill.add_argument('CONTAINER',
                                 help='specify container to kill')
+        parse_kill.add_argument('--metadata_path', '-m',
+                                default=default_metadata_path,
+                                help='metadata path, default '+default_metadata_path)
+        parse_kill.add_argument('-z',
+                                action='store_true',
+                                help='do not print any output')
         parse_kill.set_defaults(func=kill.kill.main)
 
         # link
@@ -155,6 +167,14 @@ class cli(object):
                                            help='link to a service repository host')
         parse_link.add_argument('SERVICE_HOST',
                                 help='specify service repository host to connect to')
+        parse_link.add_argument('NAME',
+                                help='specify a name for the repository')
+        parse_link.add_argument('--path',
+                                default=default_metadata_path,
+                                help='specify path where services live, default '+default_metadata_path)
+        parse_link.add_argument('--port', '-p',
+                                default='8080',
+                                help='specify port that service host is running on, default=8080')
         parse_link.add_argument('--metadata_path', '-m',
                                 default=default_metadata_path,
                                 help='metadata path, default '+default_metadata_path)
@@ -192,10 +212,15 @@ class cli(object):
 
         # logs
         parse_logs = subparsers.add_parser('logs',
-                                           help='server logs')
-        parse_logs.add_argument('HOST',
-                                default="localhost",
-                                help='specify host to get logs from')
+                                           help='container logs')
+        parse_logs.add_argument('CONTAINER',
+                                help='specify container to get logs from')
+        parse_logs.add_argument('--metadata_path', '-m',
+                                default=default_metadata_path,
+                                help='metadata path, default '+default_metadata_path)
+        parse_logs.add_argument('-z',
+                                action='store_true',
+                                help='do not print any output')
         parse_logs.set_defaults(func=logs.logs.main)
 
         # new
@@ -204,6 +229,9 @@ class cli(object):
         parse_new.add_argument('--metadata_path', '-m',
                                default=default_metadata_path,
                                help='metadata path, default '+default_metadata_path)
+        parse_new.add_argument('--toggle_default',
+                               action='store_true',
+                               help='toggle using default services, uses them by default')
         parse_new.add_argument('--no_curses', '-n',
                                action='store_true',
                                help='do not use curses')
@@ -249,11 +277,17 @@ class cli(object):
         parse_remove.add_argument('--metadata_path', '-m',
                                   default=default_metadata_path,
                                   help='metadata path, default '+default_metadata_path)
+        parse_remove.add_argument('-z',
+                                  action='store_true',
+                                  help='do not print any output')
         parse_remove.set_defaults(func=remove.remove.main)
 
         # repositories
         parse_repositories = subparsers.add_parser('repositories',
                                                    help='list repositories that are registered')
+        parse_repositories.add_argument('--metadata_path', '-m',
+                                        default=default_metadata_path,
+                                        help='metadata path, default '+default_metadata_path)
         parse_repositories.add_argument('-z',
                                     action='store_true',
                                     help='do not print any output')
@@ -302,7 +336,7 @@ class cli(object):
 
         # start
         parse_start = subparsers.add_parser('start',
-                                            help='start the api server')
+                                            help='start the api/repository service server')
         parse_start.add_argument('--metadata_path', '-m',
                                  default=default_metadata_path,
                                  help='metadata path, default '+default_metadata_path)
@@ -313,7 +347,7 @@ class cli(object):
 
         # stop
         parse_stop = subparsers.add_parser('stop',
-                                           help='stop the api server')
+                                           help='stop the api/repository service server')
         parse_stop.add_argument('--metadata_path', '-m',
                                 default=default_metadata_path,
                                 help='metadata path, default '+default_metadata_path)
@@ -322,11 +356,44 @@ class cli(object):
                                 help='do not print any output')
         parse_stop.set_defaults(func=stop.stop.main)
 
+        # subtract
+        parse_subtract = subparsers.add_parser('subtract',
+                                           help='subtract a service')
+        parse_subtract.add_argument('OS',
+                                help='specify operating system for service')
+        parse_subtract.add_argument('VERSION',
+                                help='specify version of operating system')
+        parse_subtract.add_argument('TYPE',
+                                help='specify type of service (database, environment, service, tool)')
+        parse_subtract.add_argument('NAME',
+                                help='specify name of service')
+        parse_subtract.add_argument('--metadata_path', '-m',
+                               default=default_metadata_path,
+                               help='metadata path, default '+default_metadata_path)
+        # !! TODO use default, and restructure if/else in subtract
+        parse_subtract.add_argument('--repository', '-r',
+                                help='specify repository to subtract service from, use localhost by default')
+        parse_subtract.set_defaults(func=subtract.subtract.main)
+
+        # test
+        parse_test = subparsers.add_parser('test',
+                                              help='run tests')
+        parse_test.add_argument('-c',
+                                action='store_true',
+                                help='send to coveralls')
+        parse_test.add_argument('-f',
+                                action='store_true',
+                                help='do not run tests')
+        parse_test.add_argument('--path', '-p',
+                                default=default_path,
+                                help='path to test, default '+default_path)
+        parse_test.set_defaults(func=test.test.main)
+
         # unlink
         parse_unlink = subparsers.add_parser('unlink',
-                                             help='unlink a service repository host')
-        parse_unlink.add_argument('SERVICE_HOST',
-                                  help='specify service repository host to disconnect from')
+                                             help='unlink a service repository')
+        parse_unlink.add_argument('NAME',
+                                  help='specify name of service repository to disconnect from')
         parse_unlink.add_argument('--metadata_path', '-m',
                                   default=default_metadata_path,
                                   help='metadata path, default '+default_metadata_path)
@@ -341,13 +408,16 @@ class cli(object):
         parse_update.add_argument('-r' '--repository',
                                   help='specify service repository host to get updates from')
         parse_update.add_argument('-z',
-                                  action='store_false',
+                                  action='store_true',
                                   help='do not print any output')
         parse_update.set_defaults(func=update.update.main)
 
         # version
         parse_version = subparsers.add_parser('version',
                                               help='show version')
+        parse_version.add_argument('-z',
+                                   action='store_true',
+                                   help='do not print any output')
         parse_version.set_defaults(func=version.version.main)
 
         args = parser.parse_args()
