@@ -17,6 +17,10 @@ class link(object):
         directory = os.path.expanduser(directory)
         if not os.path.exists(directory):
             os.makedirs(directory)
+
+        path = os.path.join(os.path.expanduser(args.path), 'services')
+
+        # !! TODO name must be unique
         # !! TODO
         #    test connection
         exists = False
@@ -25,13 +29,15 @@ class link(object):
                 with open(os.path.join(directory, "repositories"), 'r') as f:
                     for line in f:
                         repo = ast.literal_eval(line.strip())
-                        if repo['title'] == args.SERVICE_HOST:
+                        if repo['title'] == args.SERVICE_HOST and repo['path'] == path:
                             exists = True
             if not exists:
                 with open(os.path.join(directory, "repositories"), 'a') as f:
                     f.write("{" +
                             "'title': '"+args.SERVICE_HOST+"'," +
-                            " 'type': 'choice_menu'" +
+                            " 'type': 'choice_menu'," +
+                            " 'name': '"+args.NAME+"'," +
+                            " 'path': '"+path+"'" +
                             "}\n")
             else:
                 if not args.z:
