@@ -25,10 +25,13 @@ class remove(object):
                 for line in f:
                     container = ast.literal_eval(line.rstrip("\n"))
                     if container['container_id'] == args.CONTAINER:
-                        c = docker.Client(base_url='tcp://'+container['host']+':2375', version='1.9',
+                        c = docker.Client(base_url='tcp://'+container['host']+':2375', version='1.12',
                                           timeout=10)
                         c.remove_container(args.CONTAINER)
-                        print "removed "+container['container_id']+" on "+container['host']
+                        if not args.z:
+                            print "removed "+container['container_id']+" on "+container['host']
         except:
+            if not args.z:
+                print "unable to remove ",args.CONTAINER
             return False
         return True
