@@ -20,9 +20,10 @@ class unlink(object):
             # !! TODO need to do check if specfied repository was not there to begin with
             for line in fileinput.input(os.path.join(directory, "repositories"), inplace=True):
                 host = ast.literal_eval(line.rstrip('\n'))
-                if args.SERVICE_HOST != host['title']:
+                if args.NAME != host['name'] and directory != host['path']:
                     print "%s" % (line),
         except:
-            print "unable to remove service repository"
+            # !! TODO don't print as it will replace what's in repositories
+            #print "unable to remove service repository"
             return False
         return True
